              .title by Grant Beattie, Class 2C
;**************************************************************************
;* Sample2.asm                                                            *
;*                                                                        *
;* Demonstrates the use of conditional assembly for creating one file     *
;* that produces code for RAM or EPROM.                                   *
;**************************************************************************
; 1. This program is the same additive checksum as in SAMPLE.ASM.


;.------------------------------------------------------------------------.
;|                           EQUATES SECTION                              |
;`------------------------------------------------------------------------'

EPROM         =      1            ;Label used for conditional assembly
                                  ;  0 == RAM version
                                  ;  1 == EPROM version

LED           =      0x9000       ;2-digit LED display.
EPROMSTART    =      0xC000       ;Lowest EPROM address.
EPROMEND      =      0xFFFF       ;Highest EPROM address.

;.------------------------------------------------------------------------.
;|                               MAIN                                     |
;`------------------------------------------------------------------------'

              .AREA   Sample (ABS)
              .MODULE Sample

              .if EPROM
                 .org  0xC000
StartUp:         lds   #0x00ff    ;Initialize stack for EPROM case.
              .else
                 .org  0x1040
              .endif

Main:         ldd    #0           ;Initialize the RAM checksum variable.
              std    Checksum
              ldy    #EPROMSTART  ;Set pointer to start of test area.

Summing:      ldab   ,y           ;Read one byte from test area and
              stab   LED          ;echo it to the LED and put a copy
              stab   ByteVariable ; of it in RAM also.

              ldx    Checksum
              abx                 ;Add the byte to the total.
              stx    Checksum

              iny                 ;Point to the next location.
              cpy    #EPROMEND+1  ;All done?
              bne    Summing      ;  No, continue with next location.

              bra    .            ;  Yes done, endless loop.

              .page
;.------------------------------------------------------------------------.
;|                            CONSTANT  DATA                              |
;`------------------------------------------------------------------------'

DumbTable:    .db    0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15

Copyright:    .ascii "Copyright (c) 1995 by the person that wrote it. "
              .asciz "Hands off."


;.------------------------------------------------------------------------.
;|                             VARIABLES                                  |
;`------------------------------------------------------------------------'

              .if EPROM           ;For the EPROM case the variables will
                 .org 0x0000      ;live in the HC11's Internal RAM.  For
              .endif              ;the RAM case the variables will live
                                  ;in the 62256 just following the code.

Checksum:     .ds    2            ;Holds the final result.

ByteVariable: .ds    1            ;The byte is placed here during the
                                  ;addition process so that the RAM
                                  ;does not get lonely.


;.------------------------------------------------------------------------.
;|                           RESET VECTOR                                 |
;`------------------------------------------------------------------------'

              .if EPROM
                 .org   0xFFFE    ;Place the reset vector only for
                 .dw    StartUp   ;the EPROM CASE.
              .endif



;             ^      ^            ^       (Column settings for this example.)
;             15     22           35      IF YOU USE THE IDE SET THE TAB CHAR
;                                         OFF SO THAT IT USES SPACES INSTEAD!
