              .title by Grant Beattie,  Class 2D
;***********************************************************
;* Sample4.asm                                             *
;* THIS IS THE CONDITIONAL ASSEMBLY VERSION WITH EPROM = 1 *
;***********************************************************
;Purpose:
;  1. The program copies a string from EPROM to RAM.
;  2. As the bytes are moved, they are shown on the LED and
;     counted.
;  3. After the string is moved, the total number of bytes
;     moved is shown on the LED display.


;.---------------------------------------------------------.
;|                  EQUATES SECTION                        |
;`---------------------------------------------------------'
EPROM         =      1            ;For conditional assembly.
LED           =      0x2000       ;2-digit LED display.


;.---------------------------------------------------------.
;|                         MAIN                            |
;`---------------------------------------------------------'
              .AREA   Sample4 (ABS)
              .MODULE Sample4


            .if   EPROM
               .org  0xC000       ;For code execution from EPROM,
                                  ;  code starts at 0xC000.
Main:          lds   #0x00FF      ;Load SP for EPROM case ONLY.
                                  ;  Use 0x00FF for internal RAM,
                                  ;  or  0x9FFF for external RAM.
            .else
               .org  0x8000       ;For code execution from RAM,
            .endif                ;  code starts at 0x8000.


              clr    ByteCounter  ;Initialize the RAM variable.
              ldx    #A_string    ;X is read/source pointer.
              ldy    #Destination ;Y is write/destination pointer.

Moving:       ldaa   ,X           ;Read a char from the source.
              staa   LED          ;Echo it to the LED display.
              inc    ByteCounter  ;Increment the byte counter.
              staa   ,Y           ;Store the char at destination.

              beq    Done         ;If it's the NULL char, quit...

              inx                 ;...else advance the pointers and
              iny                 ;   return to get the next char.
              bra    Moving

Done:         ldaa   ByteCounter  ;Just for fun, show the total
              staa   LED          ;  number of bytes moved on the LED.
              bra    .            ;Finally an endless loop.
              .page
;.---------------------------------------------------------.
;|                   CONSTANT  DATA                        |
;`---------------------------------------------------------'

DumbTable:    .db    0,1,2,3,4,5,6,7,8,9,10,11,12,13,14,15

A_string:     .ascii "\r\nYou can't do this with TASM."
              .asciz '\r\n\tHa!'


;.---------------------------------------------------------.
;|                       VARIABLES                         |
;`---------------------------------------------------------'
; For code execution from EPROM, make sure the variables
; live in RAM (either Int RAM @ 0x0000 or Ext RAM @ 0x8000).

            .if    EPROM
              .org   0x0000
            .endif

ByteCounter:  .ds    1            ;Some crazy one byte variable.

Destination:  .ds    37           ;Allocate space to copy the string into.
                                  ;[There is a way to do this without
                                  ;actually counting the bytes...]
AnotherVar:   .ds    2            ;A two-byte variable (word).


;.---------------------------------------------------------.
;|                     RESET VECTOR                        |
;`---------------------------------------------------------'
; For code execution from EPROM, make sure the reset vector is
; properly placed to start our program from MAIN at power-up.

            .if   EPROM
              .org  0xFFFE
              .dw   Main
            .endif



;             ^      ^            ^       (Column settings for this example.)
;             15     22           35      IF YOU USE THE IDE SET THE TAB CHAR
;                                         OFF SO THAT IT USES SPACES INSTEAD!
